@@ -102,7 +102,7 @@ devNew <- function(type=getOption("device"), ..., scale=1, aspectRatio=1, par=NU
   # Argument 'label':
   if (!is.null(label)) {
     if (any(label == names(devList())))
-      stop("Cannot open device. Label is already used: ", label);
+      throw("Cannot open device. Label is already used: ", label);
   }
 
 
@@ -152,7 +152,7 @@ devNew <- function(type=getOption("device"), ..., scale=1, aspectRatio=1, par=NU
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Rescale 'width' & 'height' by argument 'scale'?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
-  if (!is.null(scale) && scale != 1) {
+  if (!is.null(scale) && scale != 1.0) {
     width <- args$width;
 
     # Infer 'width' from the settings
@@ -222,7 +222,7 @@ devNew <- function(type=getOption("device"), ..., scale=1, aspectRatio=1, par=NU
   # Default and user-specific parameters
   parT <- getOption("devNew/args/par", list());
   parT <- c(parT, par);
-  if (length(parT) > 0) {
+  if (length(parT) > 0L) {
     par(parT);
   }
 
@@ -232,6 +232,8 @@ devNew <- function(type=getOption("device"), ..., scale=1, aspectRatio=1, par=NU
 
 ############################################################################
 # HISTORY: 
+# 2012-11-18
+# o Replaced all stop() with throw().
 # 2012-04-30
 # o Moved devNew() to devNew.R.
 # 2012-02-26
